@@ -147,8 +147,8 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
     topLayout->addWidget(buttonBox);
 
     // We delay creation of these until needed.
-    patterns = 0;
-    placeholders = 0;
+    patterns = nullptr;
+    placeholders = nullptr;
 
     // signals and slots connections
     q->connect(selectedText, SIGNAL(toggled(bool)), q, SLOT(_k_slotSelectedTextToggled(bool)));
@@ -431,7 +431,7 @@ void KFindDialog::KFindDialogPrivate::_k_showPatterns()
         regexpDialog = KPluginTrader::createInstanceFromQuery<QDialog>(QStringLiteral("kregexpeditor"),
                        QStringLiteral("KRegExpEditor/KRegExpEditor"),
                        QString(),
-                       0,
+                       nullptr,
                        q);
         regexpDialogQueryDone = true;
     }
@@ -493,12 +493,11 @@ void KFindDialog::KFindDialogPrivate::_k_showPatterns()
             int mCursor;
         };
 
-        int i;
 
         // Populate the popup menu.
         if (!patterns) {
             patterns = new QMenu(q);
-            for (i = 0; (unsigned)i < sizeof(items) / sizeof(items[0]); i++) {
+            for (int i = 0; (unsigned)i < sizeof(items) / sizeof(items[0]); i++) {
                 patterns->addAction(new RegExpAction(patterns, i18n(items[i].description),
                                                      QLatin1String(items[i].regExp),
                                                      items[i].cursorAdjustment));
